@@ -9,5 +9,5 @@ $ENCA --license >$TESTNAME.actual || DIE=1
 diff $top_srcdir/COPYING $TESTNAME.actual || DIE=1
 $ENCA --help >$TESTNAME.actual || DIE=1
 diff $top_builddir/src/HELP $TESTNAME.actual || DIE=1
-grep '^Report bugs to .*<.*@.*>' $TESTNAME.actual >/dev/null || DIE=1
+grep '^Report bugs to .*http.*' $TESTNAME.actual >/dev/null || DIE=1
 . $srcdir/finish.sh
