@@ -17,11 +17,14 @@ else
   files=$@
 fi
 for fnm in $files; do
+  if [ "$fnm" = "NEWS" ] ; then
+    continue
+  fi
   echo "Updating $fnm..." 1>&2
   { echo "#============================================================================"
     echo "# Enca v$ver ($date)  guess and convert encoding of text files"
     echo "# Copyright (C) 2000-2003 David Necas (Yeti) <yeti@physics.muni.cz>"
-    echo "# Copyright (C) 2009-2012 Michal Cihar <michal@cihar.com>"
+    echo "# Copyright (C) 2009-2013 Michal Cihar <michal@cihar.com>"
     echo "#============================================================================"
     sed -e '1,5 d' "$fnm"
   } > tmp$$
